"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const known_headphone_1 = __importDefault(require("../../models/known_headphone"));
const arctis9_map_battery_builder_1 = __importDefault(require("./arctis9_map_battery_builder"));
const easy_battery_builder_1 = __importDefault(require("./easy_battery_builder"));
const map_battery_builder_1 = __importDefault(require("./map_battery_builder"));
class Builder {
    static build(deviceHash) {
        const builder = new Builder(deviceHash);
        const simpleHeadphone = builder.execute();
        return simpleHeadphone;
    }
    constructor(deviceHash) {
        this.deviceHash = deviceHash;
        const knownHeadphone = deviceHash.headphone;
        switch (knownHeadphone.productId) {
            case known_headphone_1.default.Arctis7X_ProductID:
            case known_headphone_1.default.Arctis1W_ProductID:
            case known_headphone_1.default.Arctis1X_ProductID:
                this.specificBuilder = new easy_battery_builder_1.default();
                break;
            case known_headphone_1.default.Arctis7P_Plus_ProductID:
            case known_headphone_1.default.Arctis7X_Plus_ProductID:
            case known_headphone_1.default.Arctis7_Plus_Destiny_ProductID:
            case known_headphone_1.default.Arctis7_Plus_ProductID:
            case known_headphone_1.default.ArctisNova7_ProductID:
            case known_headphone_1.default.ArctisNova7X_ProductID:
            case known_headphone_1.default.ArctisNova7P_ProductID:
            case known_headphone_1.default.ArctisPro_Wirelress_ProductID:
                this.specificBuilder = new map_battery_builder_1.default();
                break;
            case known_headphone_1.default.Arctis9_ProductID:
                this.specificBuilder = new arctis9_map_battery_builder_1.default();
                break;
        }
    }
    execute() {
        const { hidDevice } = this.deviceHash;
        const report = this.deviceHash.report;
        const headphone = this.deviceHash.headphone;
        let simpleHeadphone = {
            modelName: headphone.name,
            vendorId: headphone.vendorId,
            productId: headphone.productId,
            path: headphone.path,
            interfaceNum: hidDevice.interface,
            usagePage: hidDevice.usagePage,
            usage: hidDevice.usage,
        };
        if (this.specificBuilder) {
            simpleHeadphone = Object.assign(this.specificBuilder.execute(report, headphone), simpleHeadphone);
        }
        if (simpleHeadphone.batteryPercent === undefined) {
            simpleHeadphone.batteryPercent = report[headphone.batteryPercentIdx];
        }
        return simpleHeadphone;
    }
}
exports.default = Builder;
